@@ -3,21 +3,21 @@ import pandas as pd
 
 def get_optimal_dtype_int(data_col):
   max = data_col.max(); min = data_col.min()
-  if max<=np.iinfo(np.int8).max and min >= np.iinfo(np.int8).min : return "int8"
-  elif max <=np.iinfo(np.int16).max and min >=np.iinfo(np.int16).min: return "int16"
-  elif max <=np.iinfo(np.int32).max and min >=np.iinfo(np.int32).min: return "int32"
-  else: return "int64"
+  if max<=np.iinfo(np.int8).max and min >= np.iinfo(np.int8).min : return 'int8'
+  elif max <=np.iinfo(np.int16).max and min >=np.iinfo(np.int16).min: return 'int16'
+  elif max <=np.iinfo(np.int32).max and min >=np.iinfo(np.int32).min: return 'int32'
+  else: return 'int64'
 
 def get_optimal_dtype_float(data_col):
   max = data_col.max(); min = data_col.min()
-  if max <=np.finfo(np.float16).max and min >= np.finfo(np.float16).min: return "float16"
-  elif max <=np.finfo(np.float32).max and min >=np.finfo(np.float32).min: return "float32"
-  else: return "float64"
+  if max <=np.finfo(np.float16).max and min >= np.finfo(np.float16).min: return 'float16'
+  elif max <=np.finfo(np.float32).max and min >=np.finfo(np.float32).min: return 'float32'
+  else: return 'float64'
 
 def get_optimal_dtype(data_col):
   if data_col.dtype == int: return get_optimal_dtype_int(data_col)
   elif data_col.dtype == float : return get_optimal_dtype_float(data_col)
-  elif data_col.dtype == np.dtype('O'): return "object" 
+  elif data_col.dtype == np.dtype('O'): return 'object' 
   else: return data_col.dtype
 
 def get_optimal_dtype_dict(function, path):
@@ -57,11 +57,11 @@ def compress_by_path(function, path, opt_print = True, date_auto = True, categor
   #날짜 치환
   if date_auto:
     for key in dtypes.keys():
-      if dtypes[key]!="object" or not is_datetime(df_result[key][0]):
+      if dtypes[key]!='object' or not is_datetime(df_result[key][0]):
         continue
       else:
         df_result[key] = pd.to_datetime(df_result[key])
-        dtypes[key] = "datetime"
+        dtypes[key] = 'datetime'
   #카테고리 치환
   if category_auto:
     for key in dtypes.keys():
@@ -69,7 +69,7 @@ def compress_by_path(function, path, opt_print = True, date_auto = True, categor
         continue
       else:
         df_result[key] = df_result[key].astype("category")
-        dtypes[key] = "category"
+        dtypes[key] = 'category'
   #json으로 딕셔너리 저장
   import json
   json_data = json.dumps(dtypes)
@@ -92,7 +92,7 @@ def compress(data, date_auto = True, category_auto = True, json_path="dtypes.jso
         continue
       else:
         data[key] = pd.to_datetime(data[key])
-        dtypes[key] = "datetime"
+        dtypes[key] = 'datetime'
   #카테고리 치환
   if category_auto:
     for key in dtypes.keys():
@@ -100,7 +100,7 @@ def compress(data, date_auto = True, category_auto = True, json_path="dtypes.jso
         continue
       else:
         data[key] = data[key].astype("category")
-        dtypes[key] = "category"
+        dtypes[key] = 'category'
   #json으로 딕셔너리 저장
   import json
   json_data = json.dumps(dtypes)
@@ -117,7 +117,8 @@ def read_data(function, data_path, json_path, nrows=""):
   with open(json_path, "r") as a_file:
     dtypes = eval(json.load(a_file).replace('\\', ''))
   dtypes_ = dtypes
-  
+  print(dtypes_)
+
   for key in dtypes_.keys():
     if dtypes_[key] == "datetime":
       dtypes_[key] = "object"
